==> cvam_0.9.0.tar.gz: cvam/src/icodes_3.h <==
"Approximate Bayes cannot be run on a saturated model                    ",&
"Approximate Bayes procedure aborted                                     ",&
"Argument a or x is non-positive                                         ",&
"Argument beta has incorect length                                       ",&
"Argument beta has incorrect size                                        ",&
"Argument beta_cov_mat has incorrect size                                ",&
"Argument beta_hat has incorrect size                                    ",&
"Argument beta_mean has incorrect size                                   ",&
"Argument beta_series has incorrect size                                 ",&
"Argument df is non-positive                                             ",&
"Argument estimate_info has incorrect size                               ",&
"Argument estimate_var_info has incorrect size                           ",&
"Argument freq has incorrect size                                        ",&
"Argument freq_int has incorrect size                                    ",&
"Argument freq_mean has incorrect size                                   ",&
"Argument imputed_freq_int has incorrect size                            ",&
"Argument iwkp has incorect length                                       ",&
"Argument lambda has incorrect size                                      ",&
"Argument lambda is non-positive                                         ",&
"Argument lik_values has incorrect size                                  ",&
"Argument lik_var_info has incorrect size                                ",&
"Argument logP has insufficient size                                     ",&
"Argument loglik has insufficient size                                   ",&
"Argument model_matrix has incorrect number of rows                      ",&
"Argument mu has incorrect size                                          ",&
"Argument n is non-positive                                              ",&
"Argument offset has incorrect size                                      ",&
"Argument omit has incorect length                                       ",&
"Argument output_data has incorrect size                                 ",&
"Argument packed_SEs has incorrect size                                  ",&
"Argument packed_estimates has incorrect size                            ",&
"Argument packed_estimates_series has incorrect size                     ",&
"Argument piv has incorrect length                                       ",&
"Argument pred_mat has incorrect size                                    ",&
"Argument predict_var_info has incorrect size                            ",&
"Argument prob has incorrect size                                        ",&
"Argument prob is outside of [0,1]                                       ",&
"Argument prob_mean has incorrect size                                   ",&
"Argument prob_series has incorrect size                                 ",&
"Argument r has incorect dimensions                                      ",&
"Argument result_freq_int has incorrect size                             ",&
"Argument result_mat has incorrect size                                  ",&
"Argument row out of bounds                                              ",&
"Argument score has incorrect size                                       ",&
"Argument shape or scale is non-positive                                 ",&
"Argument shape1 or shape2 is non-positive                               ",&
"Argument sigma is non-positive                                          ",&
"Argument str_zero_int has incorrect size                                ",&
"Argument vhat_beta has incorrect size                                   ",&
"Argument vhat_beta_rwm has incorrect size                               ",&
"Argument wkn has incorect length                                        ",&
"Argument wkn1 or wkn2 has incorect length                               ",&
"Argument wknp has incorect dimensions                                   ",&
"Argument wkp has incorect length                                        ",&
"Argument wkp1 or wkp2 has incorect length                               ",&
"Argument wkpp has incorect dimensions                                   ",&
"Argument x has more columns than rows                                   ",&
"Argument y has incorrect size                                           ",&
"Arguments x and q have different dimensions                             ",&
"Arguments x and y have incompatible dimensions                          ",&
"Array bounds exceeded                                                   ",&
"Attempted division by zero                                              ",&
"Attempted logarithm of non-positive number                              ",&
"Bad row in data frame, positive freq for zero cells                     ",&
"Bad row in input data                                                   ",&
"Bad row in input data, positive freq for zero cells                     ",&
"Bad row in model frame mfPrior                                          ",&
"Bad row in model frame mfSeen                                           ",&
"Bad row in model frame, positive freq for zero cells                    ",&
"Bad row in pred_data                                                    ",&
"Bad row in pred_data, with positive frequency                           ",&
"Bad row in prior frame, positive freq for zero cells                    ",&
"Cycle is already done                                                   ",&
"Data inconsistent with structural zeros                                 ",&
"Degrees of freedom are not positive                                     ",&
"Dimensions of matrix arguments not conformable                          ",&
"EM algorithm aborted                                                    ",&
"Element of str_zero_int is not 0 or 1                                   ",&
"Error: stack size is too small                                          ",&
"Estimate at or near boundary                                            ",&
"Estimate has no variables                                               ",&
"Estimated cov. matrix for beta not available                            ",&
"Estimated variances may be unreliable                                   ",&
"Failed to tabulate data                                                 ",&
"First element of v is not 1.D0                                          ",&
"Hessian matrix not neg-def                                              ",&
"Hessian not neg-def                                                     ",&
"Incorrect model type                                                    ",&
"Incorrect number of cells for estimate                                  ",&
"Input argument vec has length zero                                      ",&
"Invalid value in estimate_var_info, column 3                            ",&
"Invalid value in lik_var_info, column 3                                 ",&
"Length of vec(1) greater than max_string_length                         ",&
"MCMC procedure aborted                                                  ",&
"Matrix apparently singular                                              ",&
"Matrix not positive definite                                            ",&
"Matrix vhat_beta not positive definite                                  ",&
"Matrix vhat_beta_rm not positive definite                               ",&
"Matrix vhat_beta_rwm not positive definite                              ",&
"Metropolis-Hastings got stuck                                           ",&
"Model matrix not full rank                                              ",&
"Negative frequency for row of pred_data                                 ",&
"Negative probability encountered                                        ",&
"Negative value for burn_mcmc                                            ",&
"Negative value for f_remaining                                          ",&
"Negative value for flattening constant                                  ",&
"Negative value for impute_every                                         ",&
"Negative value for iter_approx_bayes                                    ",&
"Negative value for iter_max_EM                                          ",&
"Negative value for iter_max_NR                                          ",&
"Negative value for iter_mcmc                                            ",&
"Negative value for ridge factor                                         ",&
"Negative value for start_val_jitter                                     ",&
"Negative value for thin_mcmc                                            ",&
"Negative value provided for start_val_jitter                            ",&
"Newton-Raphson aborted                                                  ",&
"Newton-Raphson failed to converge by                                    ",&
"No variables to predict                                                 ",&
"Non-positive frequency encountered                                      ",&
"Non-positive probability in denominator                                 ",&
"Non-positive value for crit_EM                                          ",&
"Non-positive value for crit_NR                                          ",&
"Non-positive value for crit_boundary                                    ",&
"Non-positive value for mcmc proposal df                                 ",&
"Non-positive value for mcmc proposal scale_fac                          ",&
"Non-square matrix encountered; square expected                          ",&
"Non-zero prob provided for structural zero                              ",&
"Non-zero starting value provided for structural zero                    ",&
"Not prepared for MCMC                                                   ",&
"Not prepared for approximate Bayes                                      ",&
"Observation found in structural zero cell                               ",&
"Output argument does not match table type                               ",&
"Overflow; cell mean became too large                                    ",&
"Overflow; jittered cell prob became too large                           ",&
"Overflow; offset too large                                              ",&
"Pivot out of bounds                                                     ",&
"Posterior distribution is not proper;                                   ",&
"Prior ridge factor ignored; model is saturated                          ",&
"Random-walk Metropolis got stuck                                        ",&
"Size of n_levels_matrix not correct                                     ",&
"Sizes of input_data and input_data_freq_int mismatched                  ",&
"Sizes of prior_data and prior_data_freq_int mismatched                  ",&
"Something bad happened                                                  ",&
"Something really bad happened                                           ",&
"Standard errors cannot be computed                                      ",&
"Start, finish positions for estimate incorrect                          ",&
"Starting value has non-positive probability                             ",&
"Step size h is non-positive                                             ",&
"Step size h is too large, exceeds a                                     ",&
"Table object is null                                                    ",&
"The model is not saturated                                              ",&
"There is no log-linear model                                            ",&
"Unable to allocate memory for object                                    ",&
"Unable to allocate workspace array component                            ",&
"Unable to deallocate memory for object                                  ",&
"Underflow; cell mean became zero                                        ",&
"Underflow; jittered cell prob became zero                               ",&
"Underflow; offset too small                                             ",&
"Upper limit b does not exceed lower limit a                             ",&
"Value for impute_approx_bayes_int not recognized                        ",&
"Value for save_prob_series_int not recognized                           ",&
"Value for stuck_limit not positive                                      ",&
"Value for type_mcmc_int not recognized                                  ",&
"Value in n_levels_matrix not correct                                    ",&
"Value of exclude_all_na_int not recognized                              ",&
"Value of method not recognized                                          ",&
"Value of model_type not recognized                                      ",&
"Value of skip_SEs_int not recognized                                    ",&
"Value of start_val_default not recognized                               ",&
"Value of start_val_default_int not recognized                           ",&
"Value of start_val_use_int not recognized                               ",&
"Value of synthetic_int not recognized                                   ",&
"Value of type_mcmc not recognized                                       ",&
"When creating mapping: allocation error                                 ",&
"When creating mapping: array bounds exceeded                            ",&
"Workspace wkn has incorrect length                                      ",&
"Workspace wkp has incorrect length                                      ",&
"Workspace wkp1 or wkp2 has incorrect length                             ",&
"assigned to structural zero cells                                       ",&
"consider using a flattening prior                                       ",&
"estimate_type not recognized                                            ",&
"iter_mcmc is not a multiple of thin_mcmc                                ",&
"logP is not concave                                                     ",&

==> cvam_0.9.1.tar.gz: cvam/src/icodes_3.h <==
"Approximate Bayes cannot be run on a saturated model                    ",&
"Approximate Bayes procedure aborted                                     ",&
"Argument a or x is non-positive                                         ",&
"Argument baseline is out of bounds                                      ",&
"Argument beta has incorect length                                       ",&
"Argument beta has incorrect size                                        ",&
"Argument beta_cov_mat has incorrect size                                ",&
"Argument beta_hat has incorrect size                                    ",&
"Argument beta_mean has incorrect size                                   ",&
"Argument beta_series has incorrect size                                 ",&
"Argument beta_vec has incorrect size                                    ",&
"Argument criterion is not positive                                      ",&
"Argument df is non-positive                                             ",&
"Argument estimate_info has incorrect size                               ",&
"Argument estimate_var_info has incorrect size                           ",&
"Argument freq has incorrect size                                        ",&
"Argument freq_int has incorrect size                                    ",&
"Argument freq_mean has incorrect size                                   ",&
"Argument hess has incorrect size                                        ",&
"Argument imputed_freq_int has incorrect size                            ",&
"Argument iter_max is negative                                           ",&
"Argument iwkp has incorect length                                       ",&
"Argument lambda has incorrect size                                      ",&
"Argument lambda is non-positive                                         ",&
"Argument lik_mat has incorrect size                                     ",&
"Argument lik_values has incorrect size                                  ",&
"Argument lik_var_info has incorrect size                                ",&
"Argument logP has insufficient size                                     ",&
"Argument loglik has insufficient size                                   ",&
"Argument model_matrix has incorrect number of rows                      ",&
"Argument mu has incorrect size                                          ",&
"Argument n is non-positive                                              ",&
"Argument offset has incorrect size                                      ",&
"Argument omit has incorect length                                       ",&
"Argument output_data has incorrect size                                 ",&
"Argument packed_SEs has incorrect size                                  ",&
"Argument packed_estimates has incorrect size                            ",&
"Argument packed_estimates_series has incorrect size                     ",&
"Argument pi_mat has incorrect size                                      ",&
"Argument piv has incorrect length                                       ",&
"Argument pred_mat has incorrect size                                    ",&
"Argument predict_var_info has incorrect size                            ",&
"Argument prob has incorrect size                                        ",&
"Argument prob is outside of [0,1]                                       ",&
"Argument prob_mean has incorrect size                                   ",&
"Argument prob_series has incorrect size                                 ",&
"Argument r has incorect dimensions                                      ",&
"Argument result_freq_int has incorrect size                             ",&
"Argument result_mat has incorrect size                                  ",&
"Argument row out of bounds                                              ",&
"Argument score has incorrect size                                       ",&
"Argument shape or scale is non-positive                                 ",&
"Argument shape1 or shape2 is non-positive                               ",&
"Argument sigma is non-positive                                          ",&
"Argument str_zero_int has incorrect size                                ",&
"Argument vhat_beta has incorrect size                                   ",&
"Argument vhat_beta_rwm has incorrect size                               ",&
"Argument vhat_beta_vec has incorrect size                               ",&
"Argument wkn has incorect length                                        ",&
"Argument wkn1 or wkn2 has incorect length                               ",&
"Argument wknp has incorect dimensions                                   ",&
"Argument wkp has incorect length                                        ",&
"Argument wkp1 or wkp2 has incorect length                               ",&
"Argument wkpp has incorect dimensions                                   ",&
"Argument x has incorrect size                                           ",&
"Argument x has more columns than rows                                   ",&
"Argument y has incorrect size                                           ",&
"Arguments x and q have different dimensions                             ",&
"Arguments x and y have incompatible dimensions                          ",&
"Array bounds exceeded                                                   ",&
"Attempted division by zero                                              ",&
"Attempted logarithm of non-positive number                              ",&
"Attempted logarithn of non-positive number                              ",&
"Bad row in data frame, positive freq for zero cells                     ",&
"Bad row in input data                                                   ",&
"Bad row in input data, positive freq for zero cells                     ",&
"Bad row in model frame mfPrior                                          ",&
"Bad row in model frame mfSeen                                           ",&
"Bad row in model frame, positive freq for zero cells                    ",&
"Bad row in pred_data                                                    ",&
"Bad row in pred_data, with positive frequency                           ",&
"Bad row in prior frame, positive freq for zero cells                    ",&
"Cycle is already done                                                   ",&
"Data inconsistent with structural zeros                                 ",&
"Degrees of freedom are not positive                                     ",&
"Dimensions of matrix arguments not conformable                          ",&
"EM algorithm aborted                                                    ",&
"Element of str_zero_int is not 0 or 1                                   ",&
"Error: stack size is too small                                          ",&
"Estimate at or near boundary                                            ",&
"Estimate has no variables                                               ",&
"Estimated cov. matrix for beta not available                            ",&
"Estimated variances may be unreliable                                   ",&
"Failed to tabulate data                                                 ",&
"First element of v is not 1.D0                                          ",&
"Hessian apparently singular                                             ",&
"Hessian matrix not neg-def                                              ",&
"Hessian not neg-def                                                     ",&
"Hessian not neg-definite                                                ",&
"Incorrect model type                                                    ",&
"Incorrect number of cells for estimate                                  ",&
"Input argument vec has length zero                                      ",&
"Invalid value in estimate_var_info, column 3                            ",&
"Invalid value in lik_var_info, column 3                                 ",&
"Length of vec(1) greater than max_string_length                         ",&
"MCMC procedure aborted                                                  ",&
"Matrix apparently singular                                              ",&
"Matrix not positive definite                                            ",&
"Matrix vhat_beta not positive definite                                  ",&
"Matrix vhat_beta_rm not positive definite                               ",&
"Matrix vhat_beta_rwm not positive definite                              ",&
"Metropolis-Hastings got stuck                                           ",&
"Model matrix not full rank                                              ",&
"Negative frequency for row of pred_data                                 ",&
"Negative likelihood encountered                                         ",&
"Negative probability encountered                                        ",&
"Negative value for burn_mcmc                                            ",&
"Negative value for f_remaining                                          ",&
"Negative value for flattening constant                                  ",&
"Negative value for impute_every                                         ",&
"Negative value for iter_approx_bayes                                    ",&
"Negative value for iter_max_EM                                          ",&
"Negative value for iter_max_NR                                          ",&
"Negative value for iter_mcmc                                            ",&
"Negative value for ridge factor                                         ",&
"Negative value for start_val_jitter                                     ",&
"Negative value for thin_mcmc                                            ",&
"Negative value in response matrix y                                     ",&
"Negative value provided for start_val_jitter                            ",&
"Newton-Raphson aborted                                                  ",&
"Newton-Raphson failed to converge by                                    ",&
"No variables to predict                                                 ",&
"Non-positive frequency encountered                                      ",&
"Non-positive probability in denominator                                 ",&
"Non-positive value for crit_EM                                          ",&
"Non-positive value for crit_NR                                          ",&
"Non-positive value for crit_boundary                                    ",&
"Non-positive value for mcmc proposal df                                 ",&
"Non-positive value for mcmc proposal scale_fac                          ",&
"Non-square matrix encountered; square expected                          ",&
"Non-zero prob provided for structural zero                              ",&
"Non-zero starting value provided for structural zero                    ",&
"Not prepared for MCMC                                                   ",&
"Not prepared for approximate Bayes                                      ",&
"Observation found in structural zero cell                               ",&
"Output argument does not match table type                               ",&
"Overflow; cell mean became too large                                    ",&
"Overflow; fitted value became too large                                 ",&
"Overflow; jittered cell prob became too large                           ",&
"Overflow; offset too large                                              ",&
"Pivot out of bounds                                                     ",&
"Posterior distribution is not proper;                                   ",&
"Prior ridge factor ignored; model is saturated                          ",&
"Random-walk Metropolis got stuck                                        ",&
"Size of n_levels_matrix not correct                                     ",&
"Sizes of input_data and input_data_freq_int mismatched                  ",&
"Sizes of prior_data and prior_data_freq_int mismatched                  ",&
"Something bad happened                                                  ",&
"Something really bad happened                                           ",&
"Standard errors cannot be computed                                      ",&
"Start, finish positions for estimate incorrect                          ",&
"Starting value has non-positive probability                             ",&
"Step size h is non-positive                                             ",&
"Step size h is too large, exceeds a                                     ",&
"Table object is null                                                    ",&
"The model is not saturated                                              ",&
"There is no log-linear model                                            ",&
"Unable to allocate array                                                ",&
"Unable to allocate memory for object                                    ",&
"Unable to allocate workspace array component                            ",&
"Unable to deallocate memory for object                                  ",&
"Underflow; cell mean became zero                                        ",&
"Underflow; jittered cell prob became zero                               ",&
"Underflow; offset too small                                             ",&
"Upper limit b does not exceed lower limit a                             ",&
"Value for impute_approx_bayes_int not recognized                        ",&
"Value for save_prob_series_int not recognized                           ",&
"Value for stuck_limit not positive                                      ",&
"Value for type_mcmc_int not recognized                                  ",&
"Value in n_levels_matrix not correct                                    ",&
"Value of exclude_all_na_int not recognized                              ",&
"Value of method not recognized                                          ",&
"Value of model_type not recognized                                      ",&
"Value of skip_SEs_int not recognized                                    ",&
"Value of start_val_default not recognized                               ",&
"Value of start_val_default_int not recognized                           ",&
"Value of start_val_use_int not recognized                               ",&
"Value of synthetic_int not recognized                                   ",&
"Value of type_mcmc not recognized                                       ",&
"When creating mapping: allocation error                                 ",&
"When creating mapping: array bounds exceeded                            ",&
"Workspace wkn has incorrect length                                      ",&
"Workspace wkp has incorrect length                                      ",&
"Workspace wkp1 or wkp2 has incorrect length                             ",&
"assigned to structural zero cells                                       ",&
"consider using a flattening prior                                       ",&
"estimate_type not recognized                                            ",&
"iter_mcmc is not a multiple of thin_mcmc                                ",&
"logP is not concave                                                     ",&
